@@ -19,6 +19,8 @@
 
 */
 
+//#define GITHUB_ISSUE_220
+
 #include "MessagesHandler.h"
 #include "MessageRouter.h"
 
@@ -42,10 +44,23 @@ using namespace std;
 
 #ifdef CONFIG_MINI_RANKS
 
+MessagesHandler::MessagesHandler() {
+
+	m_staticBuffer = NULL;
+}
+
+MessagesHandler::~MessagesHandler() {
+
+	if(m_staticBuffer != NULL) {
+		free(m_staticBuffer);
+		m_staticBuffer = NULL;
+	}
+}
+
 /**
  *
  */
-void MessagesHandler::sendAndReceiveMessagesForRankProcess(ComputeCore**cores,int miniRanksPerRank,bool*communicate){
+void MessagesHandler::sendAndReceiveMessagesForRankProcess(ComputeCore**cores,int miniRanksPerRank,bool*communicate) {
 
 	int deadMiniRanks=0;
 
@@ -131,8 +146,15 @@ void MessagesHandler::sendAndReceiveMessagesForRankProcess(ComputeCore**cores,in
  * Since all mini-ranks died, it is no longer necessasry to do
  * the communication.
  */
-	if(deadMiniRanks==miniRanksPerRank)
+	if(deadMiniRanks==miniRanksPerRank) {
+
+		/*
+		cout << "DEBUG deadMiniRanks " << deadMiniRanks;
+		cout << " miniRanksPerRank " << miniRanksPerRank << endl;
+		*/
+
 		(*communicate)=false;
+	}
 }
 
 #endif
@@ -169,7 +191,7 @@ void MessagesHandler::sendMessagesForMiniRank(MessageQueue*outbox,RingAllocator*
 		outbox->pop(aMessage);
 
 		int miniRankDestination=aMessage->getDestination();
-		int miniRankSource=aMessage->getSource();
+		//int miniRankSource=aMessage->getSource();
 
 		Rank destination=miniRankDestination/miniRanksPerRank;
 
@@ -177,17 +199,26 @@ void MessagesHandler::sendMessagesForMiniRank(MessageQueue*outbox,RingAllocator*
 		Rank source=miniRankSource/miniRanksPerRank;
 		#endif
 
-		void*buffer=aMessage->getBuffer();
-		int count=aMessage->getCount();
+		char * buffer=aMessage->getBufferBytes();
+		int bytes = aMessage->getNumberOfBytes();
 		MessageTag tag=aMessage->getTag();
 
-		#ifdef ASSERT
+#ifdef GITHUB_ISSUE_220
+		if(tag == 17) {
+
+			cout << "DEBUG buffer for message in buffered outbox" << endl;
+			Message dummy2;
+			dummy2.printBuffer(buffer, bytes);
+		}
+#endif
+
+		#ifdef CONFIG_ASSERT
 		assert(destination>=0);
 		if(destination>=m_size){
 			cout<<"Tag="<<tag<<" Destination="<<destination<<endl;
 		}
 		assert(destination<m_size);
-		assert(!(buffer==NULL && count>0));
+		assert(!(buffer==NULL && bytes >0));
 
 		// this assertion is invalid when using checksum calculation.
 		//assert(count<=(int)(MAXIMUM_MESSAGE_SIZE_IN_BYTES/sizeof(MessageUnit)));
@@ -198,15 +229,20 @@ void MessagesHandler::sendMessagesForMiniRank(MessageQueue*outbox,RingAllocator*
  * by using the original buffer directly.
  * But it is not possible because it is not thread-safe to do so.
  */
-		MessageUnit*theBuffer=(MessageUnit*)outboxBufferAllocator->allocate(MAXIMUM_MESSAGE_SIZE_IN_BYTES);
-		memcpy(theBuffer,buffer,count*sizeof(MessageUnit));
+		char * copiedBuffer=(char*)outboxBufferAllocator->allocate(MAXIMUM_MESSAGE_SIZE_IN_BYTES);
+		memcpy(copiedBuffer, buffer, bytes);
+
+#ifdef GITHUB_ISSUE_220
+		if(tag == 17) {
+			cout << "DEBUG Copying " << bytes << " bytes for tag=17" << endl;
+			Message dummy;
+			dummy.printBuffer(copiedBuffer, bytes);
+		}
+#endif
 
 /*
  * Store minirank information too at the end.
  */
-		theBuffer[count++]=miniRankSource;
-		theBuffer[count++]=miniRankDestination;
-
 		#ifdef CONFIG_DEBUG_MINI_RANK_COMMUNICATION
 		cout<<"SEND Source= "<<miniRankSource<<" Destination= "<<miniRankDestination<<" Tag= "<<tag<<endl;
 		#endif /* CONFIG_DEBUG_MINI_RANK_COMMUNICATION */
@@ -218,27 +254,46 @@ void MessagesHandler::sendMessagesForMiniRank(MessageQueue*outbox,RingAllocator*
 /*
  * Check if the buffer is already registered.
  */
-		int bufferHandle=outboxBufferAllocator->getBufferHandle(theBuffer);
+		int bufferHandle=outboxBufferAllocator->getBufferHandle(copiedBuffer);
 		bool registeredAlready=outboxBufferAllocator->isRegistered(bufferHandle);
+
 /*
  * Register the buffer as being dirty.
  */
 
 		if(!registeredAlready) {
 
-			request = this->registerMessageBuffer(buffer, m_rank, destination,
+#ifdef CONFIG_ASSERT
+			int handle = outboxBufferAllocator->getBufferHandle(copiedBuffer);
+			assert(handle >= 0);
+#endif
+
+			request = this->registerMessageBuffer(copiedBuffer, m_rank, destination,
 					tag, outboxBufferAllocator);
 
+			registeredAlready = true;
+
 		}
 
-		#ifdef ASSERT
+		#ifdef CONFIG_ASSERT
 		assert(request!=NULL);
-		assert(count>=2);
+		assert(bytes >=2);
 		#endif
 
 		//  MPI_Isend
 		//      Synchronous nonblocking. 
-		MPI_Isend(theBuffer,count,m_datatype,destination,tag,MPI_COMM_WORLD,request);
+
+		int count = bytes;
+
+#ifdef GITHUB_ISSUE_220
+		if(tag == 17) {
+			cout << "DEBUG MPI_Isend " << count << " bytes to " << destination << endl;
+			Message dummy;
+			dummy.printBuffer(copiedBuffer, count);
+		}
+#endif
+
+		MPI_Isend(copiedBuffer,count,m_datatype,destination,tag,MPI_COMM_WORLD,request);
 
 		#if 0
 		// if the message was re-routed, we don't care
@@ -262,7 +317,7 @@ void MessagesHandler::sendMessagesForMiniRank(MessageQueue*outbox,RingAllocator*
 
 #ifdef CONFIG_COMM_PERSISTENT
 
-/*	
+/*
  * receiveMessages is implemented as recommanded by Mr. George Bosilca from
 the University of Tennessee (via the Open-MPI mailing list)
 
@@ -307,7 +362,7 @@ void MessagesHandler::pumpMessageFromPersistentRing(StaticVector*inbox,RingAlloc
 
 		// the request can start again
 		MPI_Start(m_ring+m_head);
-	
+
 		// add the message in the internal inbox
 		// this inbox is not the real inbox
 		Message aMessage(incoming,count,m_rank,tag,source);
@@ -356,25 +411,53 @@ void MessagesHandler::receiveMessagesForMiniRanks(ComputeCore**cores,int miniRan
 	int count=-1;
 	MPI_Get_count(&status,datatype,&count);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(count >= 0);
 	assert(count >= 2);// we need mini-rank numbers !
 	#endif
 
+	if(m_staticBuffer == NULL) {
+
+		int requiredBytes = MAXIMUM_MESSAGE_SIZE_IN_BYTES + MESSAGE_META_DATA_SIZE;
+		m_staticBuffer = (char*) malloc(requiredBytes);
+
+#ifdef CONFIG_ASSERT
+		assert(m_staticBuffer != NULL);
+#endif
+	}
 
 	MPI_Recv(m_staticBuffer,count,datatype,actualSource,actualTag,MPI_COMM_WORLD,&status);
 
+#ifdef GITHUB_ISSUE_220
+	if(actualTag == 17) {
+		cout << "DEBUG MPI_Recv from " << actualSource << " with " << count;
+		cout << " bytes." << endl;
+
+		Message dummy;
+		dummy.printBuffer(m_staticBuffer, count);
+	}
+#endif
+
+
+	//cout << "DEBUG preloading metadata count= " << count << endl;
+
+	Message newMessage(m_staticBuffer, count, -1, actualTag, -1); // here the count is the number of MessageUnit
+	newMessage.setNumberOfBytes(count);
+
+	newMessage.loadMetaData();
+	newMessage.saveMetaData(); // ComputeCore will re-load it anyway
+
 /*
  * Get the mini-rank source and mini-rank destination.
+ * using a temporary message
  */
-	int miniRankSource=m_staticBuffer[count-2];
-	int miniRankDestination=m_staticBuffer[count-1];
+	int miniRankSource = newMessage.getSourceMiniRank();
+	int miniRankDestination = newMessage.getDestinationMiniRank();
 
 	#ifdef CONFIG_DEBUG_MINI_RANK_COMMUNICATION
 	cout<<"RECEIVE Source= "<<miniRankSource<<" Destination= "<<miniRankDestination<<" Tag= "<<actualTag<<endl;
 	#endif /* CONFIG_DEBUG_MINI_RANK_COMMUNICATION */
 
-	count-=2;
 
 	int miniRankIndex=miniRankDestination%miniRanksPerRank;
 
@@ -383,7 +466,7 @@ void MessagesHandler::receiveMessagesForMiniRanks(ComputeCore**cores,int miniRan
 	cout<<" tag is "<<actualTag<<endl;
 	#endif
 
-	MessageUnit*incoming=NULL;
+	char * incoming=NULL;
 
 	ComputeCore*core=cores[miniRankIndex];
 
@@ -409,16 +492,29 @@ void MessagesHandler::receiveMessagesForMiniRanks(ComputeCore**cores,int miniRan
 #endif /* CONFIG_USE_LOCKING */
 
 	if(count > 0){
-		incoming=(MessageUnit*)core->getBufferedInboxAllocator()->allocate(count*sizeof(MessageUnit));
+		incoming=(char*)core->getBufferedInboxAllocator()->allocate(count*sizeof(char));
 
-		#ifdef ASSERT
+		#ifdef CONFIG_ASSERT
 		assert(incoming!=NULL);
 		#endif
 
-		memcpy(incoming,m_staticBuffer,count*sizeof(MessageUnit));
+		memcpy(incoming, m_staticBuffer,count*sizeof(char));
+
+#ifdef GITHUB_ISSUE_220
+		if(actualTag == 17) {
+			cout << "DEBUG copying " << count << " bytes to incoming buffer";
+			cout << endl;
+
+			Message dummy;
+			dummy.printBuffer(incoming, count);
+		}
+#endif
+
+
 	}
 
-	Message aMessage(incoming,count,miniRankDestination,actualTag,miniRankSource);
+	Message aMessage(incoming, count, miniRankDestination, actualTag, miniRankSource);
+	aMessage.setNumberOfBytes(count);
 
 /*
  * Try to push the message. If it does not work, just try again.
@@ -438,13 +534,12 @@ void MessagesHandler::receiveMessagesForMiniRanks(ComputeCore**cores,int miniRan
 	inbox->unlock();
 #endif /* CONFIG_USE_LOCKING */
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	// this assertion is not valid for mini-ranks.
 	//assert(aMessage.getDestination() == m_rank);
 	#endif
 
 	m_receivedMessages++;
-
 }
 
 #endif
@@ -463,8 +558,8 @@ void MessagesHandler::receiveMessagesForMiniRanks(ComputeCore**cores,int miniRan
  * Starts a non-blocking reception
  */
 void MessagesHandler::startNonBlockingReception(int handle){
-	
-	#ifdef ASSERT
+
+	#ifdef CONFIG_ASSERT
 	assert(handle<m_numberOfNonBlockingReceives);
 	assert(handle>=0);
 	#endif /* ASSERT */
@@ -473,7 +568,7 @@ void MessagesHandler::startNonBlockingReception(int handle){
 
 	MPI_Request*request=m_requests+handle;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(buffer!=NULL);
 	assert(request!=NULL);
 	#endif /* ASSERT */
@@ -491,8 +586,8 @@ void MessagesHandler::init_irecv_testany(RingAllocator*inboxAllocator){
 		"CONFIG_COMM_IRECV_TESTANY",false);
 	m_receptionBuffers=(uint8_t*)__Malloc(m_bufferSize*m_numberOfNonBlockingReceives,
 		"CONFIG_COMM_IRECV_TESTANY",false);
-	
-	#ifdef ASSERT
+
+	#ifdef CONFIG_ASSERT
 	assert(m_requests!=NULL);
 	#endif
 
@@ -526,14 +621,14 @@ void MessagesHandler::receiveMessages_irecv_testany(StaticVector*inbox,RingAlloc
 	int hasCompleted=0;
 	MPI_Status status;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	int returnValue=
 	#endif /* ASSERT */
 
 	MPI_Testany(m_numberOfNonBlockingReceives,m_requests,
 		&indexOfCompletedRequest,&hasCompleted,&status);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(returnValue==MPI_SUCCESS);
 	#endif /* ASSERT */
 
@@ -548,7 +643,7 @@ void MessagesHandler::receiveMessages_irecv_testany(StaticVector*inbox,RingAlloc
 
 	uint8_t*populatedBuffer=m_receptionBuffers+indexOfCompletedRequest*m_bufferSize;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(count >= 0);
 	#endif
 
@@ -561,7 +656,7 @@ void MessagesHandler::receiveMessages_irecv_testany(StaticVector*inbox,RingAlloc
 	Message aMessage(incoming,count,m_rank,actualTag,actualSource);
 	inbox->push_back(aMessage);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(aMessage.getDestination() == m_rank);
 	#endif
 
@@ -652,11 +747,11 @@ void MessagesHandler::probeAndRead(Rank source,MessageTag tag,
 	int count=-1;
 	MPI_Get_count(&status,datatype,&count);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(count >= 0);
 	#endif
 
-	MessageUnit staticBuffer[MAXIMUM_MESSAGE_SIZE_IN_BYTES/sizeof(MessageUnit)+2];
+	char staticBuffer[MAXIMUM_MESSAGE_SIZE_IN_BYTES + MESSAGE_META_DATA_SIZE];
 
 	MPI_Recv(staticBuffer,count,datatype,actualSource,actualTag,MPI_COMM_WORLD,&status);
 
@@ -694,7 +789,7 @@ void MessagesHandler::probeAndRead(Rank source,MessageTag tag,
 
 	core->getInbox()->push_back(&aMessage);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	// this assertion is not valid for mini-ranks.
 	//assert(aMessage.getDestination() == m_rank);
 	#endif
@@ -758,7 +853,7 @@ void MessagesHandler::constructor(int*argc,char***argv){
 	m_datatype=MPI_BYTE;
 
 	#ifdef CONFIG_MINI_RANKS_disabled
-	
+
 	int provided;
 	MPI_Init_thread(argc,argv, MPI_THREAD_FUNNELED, &provided);
 	bool threads_ok = provided >= MPI_THREAD_FUNNELED;
@@ -775,7 +870,7 @@ void MessagesHandler::constructor(int*argc,char***argv){
 		cout<<"MPI_THREAD_MULTIPLE";
 	cout<<endl;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(threads_ok);
 	#endif
 
@@ -1014,7 +1109,7 @@ void MessagesHandler::sendMessages(StaticVector*outbox,RingAllocator*outboxBuffe
 		int count=aMessage->getNumberOfBytes();
 		MessageTag tag=aMessage->getTag();
 
-		#ifdef ASSERT
+		#ifdef CONFIG_ASSERT
 		assert(destination>=0);
 		if(destination>=m_size){
 			cout<<"Tag="<<tag<<" Destination="<<destination<<endl;
@@ -1048,7 +1143,7 @@ void MessagesHandler::sendMessages(StaticVector*outbox,RingAllocator*outboxBuffe
 					tag, outboxBufferAllocator);
 		}
 
-		#ifdef ASSERT
+		#ifdef CONFIG_ASSERT
 		assert(request!=NULL);
 		#endif
 
@@ -1072,7 +1167,7 @@ void MessagesHandler::sendMessages(StaticVector*outbox,RingAllocator*outboxBuffe
 
 			MPI_Request_free(request);
 
-			#ifdef ASSERT
+			#ifdef CONFIG_ASSERT
 			assert(*request==MPI_REQUEST_NULL);
 			#endif
 		}
@@ -1101,7 +1196,7 @@ void MessagesHandler::receiveMessages(StaticVector*inbox,RingAllocator*inboxAllo
 	#ifdef COMMUNICATION_IS_VERBOSE
 	cout<<"call to probeAndRead source="<<source<<""<<endl;
 	#endif /* COMMUNICATION_IS_VERBOSE */
-	
+
 	int source=MPI_ANY_SOURCE;
 	int tag=MPI_ANY_TAG;
 
@@ -1120,13 +1215,13 @@ void MessagesHandler::receiveMessages(StaticVector*inbox,RingAllocator*inboxAllo
 	int count=-1;
 	MPI_Get_count(&status,datatype,&count);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(count >= 0);
 	#endif
 
-	MessageUnit*incoming=NULL;
+	char * incoming=NULL;
 	if(count > 0){
-		incoming=(MessageUnit*)inboxAllocator->allocate(count*sizeof(MessageUnit));
+		incoming=(char*)inboxAllocator->allocate(count * sizeof(char));
 	}
 
 	MPI_Recv(incoming,count,datatype,actualSource,actualTag,MPI_COMM_WORLD,&status);
@@ -1136,7 +1231,7 @@ void MessagesHandler::receiveMessages(StaticVector*inbox,RingAllocator*inboxAllo
 
 	inbox->push_back(&aMessage);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(aMessage.getDestination() == m_rank);
 	#endif
 
@@ -1196,13 +1291,13 @@ void MessagesHandler::receiveMessagesForComputeCore(StaticVector*inbox,RingAlloc
 		Message message;
 		bufferedInbox->pop(&message);
 
-		int count=message.getCount();
-		MessageUnit*incoming=(MessageUnit*)inboxAllocator->allocate(count*sizeof(MessageUnit));
+		int count=message.getNumberOfBytes();
+		char *incoming=(char*)inboxAllocator->allocate(count*sizeof(char));
 
 /*
- * Copy the data, this is slow. 
+ * Copy the data, this is slow but required I think.
  */
-		memcpy(incoming,message.getBuffer(),count*sizeof(MessageUnit));
+		memcpy(incoming,message.getBuffer(), count*sizeof(char));
 
 /*
  * Update the buffer so that the code is thread-safe.
