@@ -28,7 +28,7 @@
 
 #include <stdlib.h>
 #include <string.h> /* for strcpy */
-#ifdef ASSERT
+#ifdef CONFIG_ASSERT
 #include <assert.h>
 #endif
 #include <iostream>
@@ -69,6 +69,7 @@ void handleSignal(int signalNumber) {
 
 ComputeCore::ComputeCore(){
 
+	m_useActorModelOnly = false;
 	m_playground.initialize(this);
 
 }
@@ -89,7 +90,7 @@ void ComputeCore::setSlaveModeObjectHandler(PluginHandle plugin,SlaveMode mode,S
 	cout<<"setSlaveModeObjectHandler "<<SLAVE_MODES[mode]<<" to "<<object<<endl;
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasSlaveMode(mode));
 	#endif
@@ -113,7 +114,7 @@ void ComputeCore::setMasterModeObjectHandler(PluginHandle plugin,MasterMode mode
 	cout<<"setMasterModeObjectHandler "<<MASTER_MODES[mode]<<" to "<<object<<endl;
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasMasterMode(mode));
 	#endif
@@ -137,7 +138,7 @@ void ComputeCore::setMessageTagObjectHandler(PluginHandle plugin,MessageTag tag,
 	cout<<"setMessageTagObjectHandler "<<MESSAGE_TAGS[tag]<<" to "<<object<<endl;
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasMessageTag(tag));
 	#endif
@@ -331,7 +332,7 @@ void ComputeCore::runWithProfiler(){
 	m_playground.bootActors();
 
 	while(isRankAlive()
-			|| (m_routerIsEnabled && !m_router.hasCompletedRelayEvents())){
+			|| (m_routerIsEnabled && !m_router.hasCompletedRelayEvents())) {
 
 		// update the debug mode.
 		// this is cheap -- it only needs to copy a boolean (usually a char)
@@ -365,6 +366,8 @@ void ComputeCore::runWithProfiler(){
 				cout << seconds * 1000 << " ms ! (tick # " << globalTicks;
 				cout << "), length is ";
 				cout << resolution << " ms" << endl;
+				m_playground.printStatus();
+				m_outboxAllocator.printBufferStatus();
 
 				status.getProcessStatus();
 				status.printMemoryMetrics();
@@ -504,7 +507,11 @@ void ComputeCore::runWithProfiler(){
 		int currentSlaveMode=m_switchMan.getSlaveMode();
 
 		uint64_t startingTime = getThreadMicroseconds();
-		processData();
+
+		if(!useActorModelOnly()) {
+			processData();
+		}
+
 		uint64_t endingTime = getThreadMicroseconds();
 
 		int difference = endingTime - startingTime;
@@ -547,23 +554,49 @@ void ComputeCore::runWithProfiler(){
 		// 4. send messages
 		sendMessages();
 
+		m_outboxAllocator.resetCount();
+
 		/* increment ticks */
 		ticks++;
 		globalTicks ++;
 	}
 
+	//cout << "DEBUG exiting ComputeCore loop" << endl;
+
+	if(m_miniRanksAreEnabled){
+#ifdef CONFIG_USE_LOCKING
+		m_bufferedOutbox.lock();
+#endif /* CONFIG_USE_LOCKING */
+
+		m_bufferedOutbox.sendKillSignal();
+
+#ifdef CONFIG_USE_LOCKING
+		m_bufferedOutbox.unlock();
+#endif /* CONFIG_USE_LOCKING */
+	}
+
+
 	if(debugModeIsEnabled() && profileGranularity)
 		m_profiler.printAllGranularities();
 }
 
 void ComputeCore::processMessages(){
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_inbox.size()>=0&&m_inbox.size()<=1);
 	#endif
 
 	if(m_inbox.size()==0)
 		return;
 
+	int i = 0;
+
+	Message * importantMessage = m_inbox.at(i);
+
+	// TODO: don't transport routing metadata if routing is disabled !
+	// save actor metadata
+	//
+	// load routing and acting metadata in the reverse order
+	// in which they were saved !!!
 
 	// if routing is enabled, we want to strip the routing tags if it
 	// is required
@@ -582,18 +615,12 @@ void ComputeCore::processMessages(){
 		}
 	}
 
-	// the message is for us...
-	// load actor metadata
-	for(int i = 0 ; i < (int) m_inbox.size() ; ++i) {
-		Message * message = m_inbox.at(i);
+	// dispatch the message
+	if(importantMessage->isActorModelMessage(m_size)) {
 
-		// save actor metadata
-		message->loadActorMetaData();
+		// cout << "DEBUG actor message detected ! m_size = " << m_size << endl;
 
-		// dispatch the message
-		if(message->isActorModelMessage()) {
-			m_playground.receiveActorMessage(message);
-		}
+		m_playground.receiveActorMessage(importantMessage);
 	}
 
 	if(m_inbox.size() > 0 && m_showCommunicationEvents){
@@ -608,10 +635,10 @@ void ComputeCore::processMessages(){
 
 
 
-	Message*message=m_inbox[0];
+	Message*message= importantMessage;
 	MessageTag messageTag=message->getTag();
 
-	#ifdef ASSERT2
+	#ifdef CONFIG_ASSERT2
 	assert(messageTag!=INVALID_HANDLE);
 	assert(m_allocatedMessageTags.count(messageTag)>0);
 	string symbol=MESSAGE_TAGS[messageTag];
@@ -627,35 +654,57 @@ void ComputeCore::processMessages(){
 
 void ComputeCore::sendMessages(){
 
-	// register actor meta-data
+/*
+ * Don't do anything when there are no messages
+ * at all.
+ * This statement needs to be after the ifdef CONFIG_ASSERT above
+ * otherwise the no resetCount call is performed on the
+ * allocator, which will produce a run-time error.
+ */
+	if(m_outbox.size()==0)
+		return;
+
+	int numberOfMessages = m_outbox.size();
+
+// first, allocate new a new buffer for each message.
+
+	bool forceMemoryReallocation = true;
 
 	for(int i = 0 ; i < (int) m_outbox.size() ; ++i) {
-		Message * message = m_outbox.at(i);
+		Message * aMessage = m_outbox.at(i);
 
-		// we need a buffer to store the actor metadata
-		if(message->getBuffer() == NULL) {
-			void * buffer = m_outboxAllocator.allocate(0);
-			message->setBuffer((MessageUnit*)buffer);
+		// we need space for routing information
+		// also, if this is a control message sent to all, we need
+		// to allocate new buffers.
+		// There is no problem at rewritting buffers that have non-null buffers,
+		// but it is useless if the buffer is used once.
+		// So numberOfMessages==m_size is just an optimization.
+		if(forceMemoryReallocation
+				|| ( aMessage->getBuffer()==NULL||numberOfMessages==m_size)) {
+
+			#ifdef CONFIG_ASSERT
+			assert(forceMemoryReallocation || aMessage->getCount()==0||numberOfMessages==m_size);
+			#endif
+
+			char * buffer=(char*)m_outboxAllocator.allocate(MAXIMUM_MESSAGE_SIZE_IN_BYTES);
+
+			#ifdef CONFIG_ASSERT
+			assert(buffer!=NULL);
+			#endif
+
+			// copy the old stuff too
+			if(aMessage->getBuffer()!=NULL) {
+
+				memcpy(buffer, aMessage->getBuffer(), aMessage->getNumberOfBytes() * sizeof(char));
+			}
+
+			aMessage->setBuffer(buffer);
 		}
-
-		/*
-		cout << "DEBUG Before saving ";
-		message->printActorMetaData();
-		cout << endl;
-		*/
-
-		// save actor metadata
-		// routed message already have this
-		if(!m_router.isRoutingTag(message->getTag()))
-			message->saveActorMetaData();
-
-		/*
-		cout << "DEBUG After saving ";
-		message->printActorMetaData();
-		cout << endl;
-		*/
 	}
 
+
+// run some assertions.
+
 /*
  * What follows is all the crap for checking some assertions and
  * profiling events.
@@ -663,7 +712,7 @@ void ComputeCore::sendMessages(){
  * of this method.
  */
 	// assert that we did not overflow the ring
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	if(m_outboxAllocator.getCount() > m_maximumAllocatedOutboxBuffers){
 		cout<<"Rank "<<m_rank<<" Error, allocated "<<m_outboxAllocator.getCount()<<" buffers, but maximum is ";
 		cout<<m_maximumAllocatedOutboxBuffers<<endl;
@@ -673,7 +722,6 @@ void ComputeCore::sendMessages(){
 
 	assert(m_outboxAllocator.getCount()<=m_maximumAllocatedOutboxBuffers);
 
-	m_outboxAllocator.resetCount();
 	int messagesToSend=m_outbox.size();
 	if(messagesToSend>m_maximumNumberOfOutboxMessages){
 		cout<<"Fatal: "<<messagesToSend<<" messages to send, but max is "<<m_maximumNumberOfOutboxMessages<<endl;
@@ -693,15 +741,44 @@ void ComputeCore::sendMessages(){
 
 	#endif
 
-/*
- * Don't do anything when there are no messages
- * at all.
- * This statement needs to be after the ifdef ASSERT above
- * otherwise the no resetCount call is performed on the
- * allocator, which will produce a run-time error.
- */
-	if(m_outbox.size()==0)
-		return;
+///////////////////////----------------
+
+
+	// old useless code
+#ifdef OLD_ACTOR_META_CODE
+	// register actor meta-data
+
+	for(int i = 0 ; i < (int) m_outbox.size() ; ++i) {
+		Message * message = m_outbox.at(i);
+
+		// we need a buffer to store the actor metadata
+		if(message->getBuffer() == NULL) {
+			void * buffer = m_outboxAllocator.allocate(0);
+			message->setBuffer(buffer);
+		}
+
+		/*
+		cout << "DEBUG Before saving ";
+		message->printActorMetaData();
+		cout << endl;
+		*/
+
+		// save actor metadata
+		// routed message already have this
+		/*if(!m_router.isRoutingTag(message->getTag()))
+			message->saveActorMetaData();
+			*/
+
+		/*
+		cout << "DEBUG After saving ";
+		message->printActorMetaData();
+		cout << endl;
+		*/
+
+
+	}
+#endif
+
 
 	// route messages if the router is enabled
 	if(m_routerIsEnabled){
@@ -710,6 +787,33 @@ void ComputeCore::sendMessages(){
 		m_router.routeOutcomingMessages();
 	}
 
+	// save metadata
+	for(int i=0;i<(int)m_outbox.size();i++){
+
+		Message * message = m_outbox.at(i);
+
+		// TODO: only save routing metadata if routing is activated !
+		// this will save 8 bytes per transport operation
+
+		// save the minirank number because the mini-rank subsystem needs that
+
+		if(m_miniRanksAreEnabled) {
+			message->setMiniRanks(message->getSource(), message->getDestination());
+		}
+
+		message->saveMetaData();
+
+#ifdef CONFIG_ASSERT
+		testMessage(message);
+#endif
+	}
+
+	// add checksums if necessary
+	if(m_doChecksum){
+		addMessageChecksums();
+	}
+
+
 	// parameters.showCommunicationEvents()
 	if( m_showCommunicationEvents && m_outbox.size() > 0){
 		uint64_t microseconds=getMicroseconds() - m_startingTimeMicroseconds;
@@ -722,13 +826,44 @@ void ComputeCore::sendMessages(){
 
 	for(int i=0;i<(int)m_outbox.size();i++){
 		m_tickLogger.logSendMessage(INVALID_HANDLE);
+
+#ifdef GITHUB_ISSUE_220
+		Message * message = m_outbox.at(i);
+
+		if(message->getTag() == 17 && message->getDestination() == 2) {
+
+			cout << "DEBUG before sending inside mini-rank" << endl;
+			message->print();
+		}
+#endif
 	}
 
-	// add checksums if necessary
-	if(m_doChecksum){
-		addMessageChecksums();
+
+	#ifdef CONFIG_ASSERT
+
+	for(int i=0;i<(int)m_outbox.size();i++){
+
+		Message * message = m_outbox.at(i);
+
+#ifdef CONFIG_ASSERT
+		testMessage(message);
+#endif
+
+//#define INVESTIGATION_2013_11_04
+#ifdef INVESTIGATION_2013_11_04
+		if(message->getTag() == 17) {
+
+			cout << "DEBUG INVESTIGATION_2013_11_04 ";
+			cout << (void*) message->getBufferBytes();
+			cout << endl;
+		}
+#endif
+
+
 	}
 
+#endif
+
 	// finally, send the messages
 
 	if(!m_miniRanksAreEnabled){
@@ -747,24 +882,26 @@ void ComputeCore::sendMessages(){
 void ComputeCore::addMessageChecksums(){
 
 	int count=m_outbox.size();
-	for(int i=0;i<count;i++){
-		MessageUnit*data=m_outbox.at(i)->getBuffer();
-		int numberOfUnits=m_outbox.at(i)->getCount();
 
+	for(int i=0;i<count;i++){
+
+		char * data=m_outbox.at(i)->getBufferBytes();
+		int numberOfBytes = m_outbox.at(i)->getNumberOfBytes();
+
+		/*
 		// don't compute checksum for empty messages
-		if(numberOfUnits==0){
+		if(bytes == 0){
 			continue;
 		}
-
-		int numberOfBytes=sizeof(MessageUnit)*numberOfUnits;
+		*/
 
 		uint8_t*bytes=(uint8_t*)data;
 
 		uint32_t crc32=computeCyclicRedundancyCode32(bytes,numberOfBytes);
 
-		data[numberOfUnits]=crc32;
+		memcpy(bytes + numberOfBytes, &crc32, sizeof(crc32));
 
-		m_outbox.at(i)->setCount(numberOfUnits+1);
+		m_outbox.at(i)->setNumberOfBytes(numberOfBytes + sizeof(crc32));
 	}
 
 }
@@ -773,28 +910,37 @@ void ComputeCore::verifyMessageChecksums(){
 
 	int count=m_inbox.size();
 	for(int i=0;i<count;i++){
-		MessageUnit*data=m_inbox.at(i)->getBuffer();
 
-		// this contains the checksum unit too.
-		int numberOfUnits=m_inbox.at(i)->getCount();
+		Message * message = m_inbox.at(i);
 
-		// don't compute checksum for empty messages
-		if(numberOfUnits==0){
-			continue;
-		}
+		uint32_t crc32 = 0;
+		char * data = message->getBufferBytes();
 
-		// the last MessageUnit contains the crc32.
-		// note that the CRC32 feature only works for MessageUnit at least
+#ifdef CONFIG_ASSERT
+		assert(message->getNumberOfBytes() >= (int) sizeof(crc32));
+#endif
+
+		message->setNumberOfBytes(message->getNumberOfBytes() - sizeof(crc32));
+
+#ifdef CONFIG_ASSERT
+		assert(message->getNumberOfBytes() >= 0);
+#endif
+
+		// the last Message Unit contains the crc32.
+		// note that the CRC32 feature only works for Message Unit at least
 		// 32 bits.
-		int numberOfBytes=sizeof(MessageUnit)*(numberOfUnits-1);
+		int numberOfBytes = m_inbox.at(i)->getNumberOfBytes();
 
 		uint8_t*bytes=(uint8_t*)data;
 
 		// compute the checksum, excluding the reference checksum
 		// from the data
-		uint32_t crc32=computeCyclicRedundancyCode32(bytes,numberOfBytes);
+		crc32 = computeCyclicRedundancyCode32((uint8_t*)bytes, numberOfBytes);
 
-		uint32_t expectedChecksum=data[numberOfUnits-1];
+		uint32_t expectedChecksum = 0;
+
+		memcpy(&expectedChecksum, data + numberOfBytes,
+			sizeof(expectedChecksum));
 
 		#ifdef CONFIG_SHOW_CHECKSUM
 		cout<<" Expected checksum (CRC32): "<<hex<<expectedChecksum<<endl;
@@ -804,25 +950,14 @@ void ComputeCore::verifyMessageChecksums(){
 		if(crc32 != expectedChecksum){
 			Message*message=m_inbox.at(i);
 			cout<<"Error: RayPlatform detected a message corruption !"<<endl;
-			cout<<" Tag: "<<MESSAGE_TAGS[message->getTag()]<<endl;
+			cout<<" Tag: " << message->getTag() << endl;
 			cout<<" Source: "<<message->getSource()<<endl;
 			cout<<" Destination: "<<message->getDestination()<<endl;
-			cout<<" sizeof(MessageUnit): "<<sizeof(MessageUnit)<<endl;
-			cout<<" Count (excluding checksum): "<<numberOfUnits-1<<endl;
+			cout<<" Bytes (excluding checksum): "<< numberOfBytes << endl;
 			cout<<" Expected checksum (CRC32): "<<hex<<expectedChecksum<<endl;
 			cout<<" Actual checksum (CRC32): "<<hex<<crc32<<dec<<endl;
 		}
 
-		#ifdef ASSERT
-		assert(numberOfUnits>=2);
-		#endif
-
-		// remove the checksum
-		m_inbox.at(i)->setCount(numberOfUnits-1);
-
-		#ifdef ASSERT
-		assert(numberOfUnits>=1);
-		#endif
 	}
 
 }
@@ -850,16 +985,42 @@ void ComputeCore::receiveMessages(){
 
 	}
 
+	if(m_inbox.size() == 0)
+		return;
+
+	// load metadata.
+
+	//cout << "DEBUG loading message metadata." << endl;
+
+	Message * importantMessage = m_inbox.at(0);
+
 	// verify checksums and remove them
+	// messages are line onions, you have to peel them from the outside to the inside
 	if(m_doChecksum){
 		verifyMessageChecksums();
 	}
 
+	importantMessage->loadMetaData();
+	importantMessage->saveMetaData();
+
+#ifdef GITHUB_ISSUE_220
+	if(importantMessage->getTag() == 17 && getRank() == 2) {
+		cout << "DEBUG ComputeCore receives message!" << endl;
+		importantMessage->print();
+	}
+#endif
+
+#ifdef CONFIG_ASSERT
+	testMessage(importantMessage);
+
+	//testMessage(importantMessage);
+#endif
+
 	for(int i=0;i<(int)m_inbox.size();i++){
 		m_tickLogger.logReceivedMessage(INVALID_HANDLE);
 	}
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	int receivedMessages=m_inbox.size();
 
 	if(receivedMessages>m_maximumNumberOfInboxMessages)
@@ -868,6 +1029,8 @@ void ComputeCore::receiveMessages(){
 	assert(receivedMessages<=m_maximumNumberOfInboxMessages);
 	#endif
 
+	// remove the header now !
+	importantMessage->loadMetaData();
 }
 
 /** process data my calling current slave and master methods */
@@ -919,7 +1082,7 @@ void ComputeCore::processData(){
 void ComputeCore::constructor(int argc,char**argv,int miniRankNumber,int numberOfMiniRanks,int miniRanksPerRank,
 		MessagesHandler*messagesHandler){
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(miniRankNumber<numberOfMiniRanks);
 	assert(miniRanksPerRank<=numberOfMiniRanks);
 	assert(numberOfMiniRanks>=1);
@@ -943,7 +1106,7 @@ void ComputeCore::constructor(int argc,char**argv,int miniRankNumber,int numberO
 	#endif
 
 	// checksum calculation is only tested
-	// for cases with sizeof(MessageUnit)>=4 bytes
+	// for cases with sizeof(Message Unit)>=4 bytes
 
 	m_routerIsEnabled=false;
 
@@ -1070,29 +1233,77 @@ void ComputeCore::configureEngine() {
 	cout<<"[ComputeCore] the outbox capacity is "<<m_maximumNumberOfOutboxMessages<<" message"<<endl;
 	#endif
 
-	int maximumMessageSizeInByte=MAXIMUM_MESSAGE_SIZE_IN_BYTES;
+	int maximumMessageSizeInBytes = MAXIMUM_MESSAGE_SIZE_IN_BYTES;
 
 	bool useActorModel = true;
 
 	// add a message unit to store the checksum or the routing information
-	// with 64-bit integers as MessageUnit, this is 4008 bytes or 501 MessageUnit maximum
+	// with 64-bit integers as Message Unit, this is 4008 bytes or 501 Message Unit maximum
 	// also add 8 bytes for actor metadata
+	// finally, add 4 bytes for the checksum, if necessary.
+
 	if(m_miniRanksAreEnabled || m_doChecksum || m_routerIsEnabled || useActorModel){
-		if(sizeof(MessageUnit)>=4){
-			maximumMessageSizeInByte+=(2 + 2)*sizeof(MessageUnit);
-		}else if(sizeof(MessageUnit)>=2){
-			maximumMessageSizeInByte+=(2 + 2) *2*sizeof(MessageUnit);
-		}else{
-			maximumMessageSizeInByte+=(2 + 2) *4*sizeof(MessageUnit);
+
+		int headerSize = 0;
+
+		headerSize = MESSAGE_META_DATA_SIZE;
+
+		/*
+		// actor model
+		headerSize += ( 2 * sizeof(int) * sizeof(char) );
+
+		// routing
+		headerSize += ( 2 * sizeof(int) * sizeof(char));
+
+		// checksum
+		headerSize += ( 1 * sizeof(uint32_t) * sizeof(char) );
+*/
+
+/*
+		cout << "DEBUG MAXIMUM_MESSAGE_SIZE_IN_BYTES " << MAXIMUM_MESSAGE_SIZE_IN_BYTES;
+		cout << " headerSize " << headerSize << endl;
+		*/
+
+		// align this on 8 bytes because there is still something in the code
+		// that is incorrect apparently.
+		//
+		// TODO: find why this needs to be aligned on 8 bytes. This is related to 
+		// sizeof(MessageUnit) being 8 bytes.
+		//
+		// => it is likely because of the underlying system that evolved to
+		// use 64 bits per message unit.
+
+		bool align = true;
+		//align = false;
+
+		int base = 8;
+		int remainder = headerSize % base;
+
+		if(align && remainder != 0) {
+
+			int toAdd = base - remainder;
+
+			headerSize += toAdd;
 		}
+
+		//cout << " headerSize (with padding) " << headerSize << endl;
+
+		maximumMessageSizeInBytes += headerSize;
 	}
 
+	//cout << "DEBUG maximumMessageSizeInBytes " << maximumMessageSizeInBytes << endl;
+
+#ifdef CONFIG_ASSERT
+	assert(maximumMessageSizeInBytes >= MAXIMUM_MESSAGE_SIZE_IN_BYTES);
+	assert(maximumMessageSizeInBytes >= MAXIMUM_MESSAGE_SIZE_IN_BYTES + 20);// we need 20 bytes for storing message header
+#endif
+
 	m_inboxAllocator.constructor(m_maximumAllocatedInboxBuffers,
-		maximumMessageSizeInByte,
+		maximumMessageSizeInBytes,
 		"RAY_MALLOC_TYPE_INBOX_ALLOCATOR",false);
 
 	m_outboxAllocator.constructor(m_maximumAllocatedOutboxBuffers,
-		maximumMessageSizeInByte,
+		maximumMessageSizeInBytes,
 		"RAY_MALLOC_TYPE_OUTBOX_ALLOCATOR",false);
 
 	if(m_miniRanksAreEnabled){
@@ -1102,18 +1313,18 @@ void ComputeCore::configureEngine() {
 		#endif
 
 		m_bufferedInboxAllocator.constructor(m_maximumAllocatedOutboxBuffers,
-			maximumMessageSizeInByte,
+			maximumMessageSizeInBytes,
 			"RAY_MALLOC_TYPE_INBOX_ALLOCATOR/Buffered",false);
 
 		m_bufferedOutboxAllocator.constructor(m_maximumAllocatedOutboxBuffers,
-			maximumMessageSizeInByte,
+			maximumMessageSizeInBytes,
 			"RAY_MALLOC_TYPE_OUTBOX_ALLOCATOR/Buffered",false);
 
 	}
 
 	#ifdef CONFIG_DEBUG_CORE
-	cout<<"[ComputeCore] allocated "<<m_maximumAllocatedInboxBuffers<<" buffers of size "<<maximumMessageSizeInByte<<" for inbox messages"<<endl;
-	cout<<"[ComputeCore] allocated "<<m_maximumAllocatedOutboxBuffers<<" buffers of size "<<maximumMessageSizeInByte<<" for outbox messages"<<endl;
+	cout<<"[ComputeCore] allocated "<<m_maximumAllocatedInboxBuffers<<" buffers of size "<<maximumMessageSizeInBytes<<" for inbox messages"<<endl;
+	cout<<"[ComputeCore] allocated "<<m_maximumAllocatedOutboxBuffers<<" buffers of size "<<maximumMessageSizeInBytes<<" for outbox messages"<<endl;
 	#endif
 
 }
@@ -1291,12 +1502,12 @@ void ComputeCore::setSlaveModeSymbol(PluginHandle plugin,SlaveMode mode,const ch
 	if(!validationSlaveModeRange(plugin,mode))
 		return;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(mode>=0);
 	assert(mode<MAXIMUM_NUMBER_OF_SLAVE_HANDLERS);
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasSlaveMode(mode));
 	#endif
@@ -1335,12 +1546,12 @@ void ComputeCore::setMasterModeSymbol(PluginHandle plugin,MasterMode mode,const
 	if(!validationMasterModeRange(plugin,mode))
 		return;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(mode>=0);
 	assert(mode<MAXIMUM_NUMBER_OF_MASTER_HANDLERS);
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasMasterMode(mode));
 	#endif
@@ -1374,12 +1585,12 @@ void ComputeCore::setMessageTagSymbol(PluginHandle plugin,MessageTag tag,const c
 	if(!validationMessageTagRange(plugin,tag))
 		return;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(tag>=0);
 	assert(tag<MAXIMUM_NUMBER_OF_TAG_HANDLERS);
 	#endif
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	assert(m_plugins[plugin].hasMessageTag(tag));
 	#endif
@@ -1391,6 +1602,16 @@ void ComputeCore::setMessageTagSymbol(PluginHandle plugin,MessageTag tag,const c
 	m_registeredMessageTagSymbols.insert(tag);
 
 	m_messageTagSymbols[symbol]=tag;
+
+	if(debugModeIsEnabled()) {
+
+		cout << "DEBUG----- <MessageTag><Name>";
+		cout << symbol;
+		cout << "</Name><Value>";
+		cout << tag;
+		cout << "</Value></MessageTag>";
+		cout << endl;
+	}
 }
 
 PluginHandle ComputeCore::allocatePluginHandle(){
@@ -1413,7 +1634,7 @@ SlaveMode ComputeCore::allocateSlaveModeHandle(PluginHandle plugin){
 		return INVALID_HANDLE;
 
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	#endif
 
@@ -1429,7 +1650,7 @@ SlaveMode ComputeCore::allocateSlaveModeHandle(PluginHandle plugin){
 	if(!validationSlaveModeRange(plugin,handle))
 		return INVALID_HANDLE;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedSlaveModes.count(handle)==0);
 	#endif
 
@@ -1437,7 +1658,7 @@ SlaveMode ComputeCore::allocateSlaveModeHandle(PluginHandle plugin){
 
 	m_plugins[plugin].addAllocatedSlaveMode(handle);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedSlaveModes.count(handle)>0);
 	assert(m_plugins[plugin].hasSlaveMode(handle));
 	#endif
@@ -1450,7 +1671,7 @@ MasterMode ComputeCore::allocateMasterModeHandle(PluginHandle plugin){
 	if(!validationPluginAllocated(plugin))
 		return INVALID_HANDLE;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	#endif
 
@@ -1466,7 +1687,7 @@ MasterMode ComputeCore::allocateMasterModeHandle(PluginHandle plugin){
 	if(!validationMasterModeRange(plugin,handle))
 		return INVALID_HANDLE;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedMasterModes.count(handle)==0);
 	#endif
 
@@ -1474,7 +1695,7 @@ MasterMode ComputeCore::allocateMasterModeHandle(PluginHandle plugin){
 
 	m_plugins[plugin].addAllocatedMasterMode(handle);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedMasterModes.count(handle)>0);
 	assert(m_plugins[plugin].hasMasterMode(handle));
 	#endif
@@ -1487,7 +1708,7 @@ MessageTag ComputeCore::allocateMessageTagHandle(PluginHandle plugin){
 	if(!validationPluginAllocated(plugin))
 		return INVALID_HANDLE;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_plugins.count(plugin)>0);
 	#endif
 
@@ -1503,7 +1724,7 @@ MessageTag ComputeCore::allocateMessageTagHandle(PluginHandle plugin){
 	if(!validationMessageTagRange(plugin,handle))
 		return INVALID_HANDLE;
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedMessageTags.count(handle)==0);
 	#endif
 
@@ -1511,7 +1732,7 @@ MessageTag ComputeCore::allocateMessageTagHandle(PluginHandle plugin){
 
 	m_plugins[plugin].addAllocatedMessageTag(handle);
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(m_allocatedMessageTags.count(handle)>0);
 	assert(m_plugins[plugin].hasMessageTag(handle));
 	#endif
@@ -2146,7 +2367,35 @@ bool ComputeCore::isRankAlive() const {
 	if(m_playground.hasAliveActors())
 		return true;
 
+	// if only the actor model is used, the rank is basically
+	// dead if all its actors are dead !
+	if(useActorModelOnly())
+		return false;
+
+	// otherwise, we use the life indicator for the rank
+
 	return m_alive;
 }
 
+bool ComputeCore::useActorModelOnly() const {
 
+	return m_useActorModelOnly;
+}
+
+void ComputeCore::setActorModelOnly() {
+
+	m_useActorModelOnly = true;
+}
+
+void ComputeCore::spawn(Actor * actor) {
+
+	spawnActor( actor );
+}
+
+#ifdef CONFIG_ASSERT
+void ComputeCore::testMessage(Message * message) {
+
+	message->runAssertions(getSize(), m_routerIsEnabled,
+			m_miniRanksAreEnabled);
+}
+#endif
