@@ -41,7 +41,9 @@ void Mock::resolveSymbols(ComputeCore*core){
 		Mother * mother = new Mother();
 
 		mother->setParameters(parameters);
-		m_core->spawnActor(mother);
+		m_core->spawn(mother);
+
+		m_core->setActorModelOnly();
 	}
 }
 
