@@ -548,7 +548,7 @@ void Parameters::parseCommands(){
 
 			int meanFragmentLength=0;
 			int standardDeviation=0;
-			#ifdef ASSERT
+			#ifdef CONFIG_ASSERT
 			assert(items==1 or items==3);
 			#endif
 
@@ -581,7 +581,7 @@ void Parameters::parseCommands(){
 					cout<<" Standard deviation: automatic detection"<<endl;
 				}
 			}else{
-				#ifdef ASSERT
+				#ifdef CONFIG_ASSERT
 				assert(false);
 				#endif
 			}
@@ -654,7 +654,7 @@ void Parameters::parseCommands(){
 
 			int meanFragmentLength=0;
 			int standardDeviation=0;
-			#ifdef ASSERT
+			#ifdef CONFIG_ASSERT
 			assert(items==4 or items==2);
 			#endif
 
@@ -953,7 +953,7 @@ void Parameters::parseCommands(){
  * There is not really any limit on the number of files.
  * The limit is on the number of paired libraries (2^sizeof(uint16_t)).
  */
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	LibraryHandle maximumLibraryIndex=0;
 	maximumLibraryIndex--;
 
@@ -981,7 +981,7 @@ void Parameters::writeCommandFile(){
 
 	int numberOfRays=getSize();
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(numberOfRays%m_numberOfMiniRanksPerRank==0);
 	#endif
 
@@ -1025,7 +1025,7 @@ void Parameters::writeSmartCommand() {
 
 	int numberOfRays=getSize();
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(numberOfRays%m_numberOfMiniRanksPerRank==0);
 	#endif
 
@@ -1135,7 +1135,7 @@ void Parameters::setDefaultRoutingOptions() {
 
 		radix--;
 
-		if(radix == 1)
+		if(radix <= 1)
 			break;
 
 		if(foundSolution)
@@ -1407,7 +1407,7 @@ int Parameters::getNumberOfLibraries(){
 }
 
 LargeCount Parameters::getNumberOfSequences(int file){
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	if(file>=(int)m_numberOfSequencesInFile.size())
 		cout<<"Error File= "<<file<<" Files: "<<m_numberOfSequencesInFile.size()<<endl;
 
@@ -1529,6 +1529,10 @@ void Parameters::showUsage(){
 	cout<<"    - quantification of transcript expression"<<endl;
 	cout<<"    - taxonomy profiling of samples (with Ray Communities)"<<endl;
 	cout<<"    - gene ontology profiling of samples (with Ray Ontologies)"<<endl;
+	cout<<endl;
+
+	cout<<"    - compare DNA samples using words (Ray -run-surveyor ...; see Ray Surveyor options)"<<endl;
+
 	cout<<endl;
 	showOption("-help","Displays this help page.");
 	cout<<endl;
@@ -1598,6 +1602,22 @@ void Parameters::showUsage(){
 	showOptionDescription("Other name: -output");
 	cout<<endl;
 
+	cout << "  Ray Surveyor options" << endl;
+	cout<<endl;
+	showOption("-run-surveyor", "Runs Ray Surveyor to compare samples.");
+	showOptionDescription("See Documentation/Ray-Surveyor.md");
+	showOptionDescription("This workflow generates:");
+	showOptionDescription("RayOutput/Surveyor/SimilarityMatrix.tsv is a similarity Gramian matrix based on shared DNA words");
+	showOptionDescription("RayOutput/Surveyor/DistanceMatrix.tsv is a distance matrix (kernel-based).");
+
+	showOption("-read-sample-graph SampleName SampleGraphFile", "Reads a sample graph (generated with -write-kmers)");
+
+	cout<<endl;
+
+
+
+
+
 	cout<<"  Assembly options (defaults work well)"<<endl;
 	cout<<endl;
 
@@ -1622,6 +1642,11 @@ void Parameters::showUsage(){
 
 	showOption("-disable-scaffolder","Disables the scaffolder.");
 	cout<<endl;
+
+	showOption("-minimum-seed-length minimumSeedLength",
+		"Changes the minimum seed length, default is 100 nucleotides");
+	cout<<endl;
+
 	showOption("-minimum-contig-length minimumContigLength",
 		"Changes the minimum contig length, default is 100 nucleotides");
 	cout<<endl;
@@ -1710,10 +1735,15 @@ void Parameters::showUsage(){
 	showOptionDescription("An AMOS file contains read positions on contigs.");
 	showOptionDescription("Can be opened with software with graphical user interface.");
 	cout<<endl;
+
 	showOption("-write-kmers","Writes k-mer graph to RayOutput/kmers.txt");
 	showOptionDescription("The resulting file is not utilised by Ray.");
 	showOptionDescription("The resulting file is very large.");
 	cout<<endl;
+
+	showOption("-graph-only","Exits after building graph.");
+	cout<<endl;
+
 	showOption("-write-read-markers","Writes read markers to disk.");
 	cout<<endl;
 	showOption("-write-seeds","Writes seed DNA sequences to RayOutput/Rank<rank>.RaySeeds.fasta");
@@ -2028,7 +2058,7 @@ Rank Parameters::getRankFromGlobalId(ReadHandle & a){
 		rank=m_size-1;
 	}
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 
 	if(rank<0){
 		cout<<"Error: rank is < 0, rank: "<<rank<<" ReadHandle: "<<a<<" elementsPerRank: "<<elementsPerRank;
@@ -2281,7 +2311,7 @@ bool Parameters::hasConfigurationOption(const char*string,int count){
 
 double Parameters::getConfigurationDouble(const char*string,int offset){
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(hasConfigurationOption(string,offset+1));
 	#endif
 
@@ -2303,7 +2333,7 @@ double Parameters::getConfigurationDouble(const char*string,int offset){
 
 const char*Parameters::getConfigurationString(const char*string,int offset){
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(hasConfigurationOption(string,offset+1));
 	#endif
 
@@ -2319,7 +2349,7 @@ const char*Parameters::getConfigurationString(const char*string,int offset){
 
 
 uint64_t Parameters::getConfigurationInteger(const char*string,int offset){
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(hasConfigurationOption(string,offset+1));
 	#endif
 
@@ -2368,7 +2398,7 @@ void Parameters::__shuffleOperationCodes(){
 		}
 	}
 
-	#ifdef ASSERT
+	#ifdef CONFIG_ASSERT
 	assert(newCommands.size()==m_commands.size());
 	#endif
 
